from datetime import datetime
from typing import List, Optional, Dict, Any

from janis_core import *
from janis_core.types.common_data_types import Boolean, String

Promoterwise_V0_1_0 = CommandToolBuilder(tool="promoterwise", base_command=["promoterwise"], inputs=[ToolInput(tag="in_align", input_type=Boolean(optional=True), prefix="-align", doc=InputDocumentation(doc="[normal/motif] use normal DBA or motif alignment [normal]")), ToolInput(tag="in_query_start_restriction", input_type=Boolean(optional=True), prefix="-s", doc=InputDocumentation(doc="query start position restriction")), ToolInput(tag="in_query_end_position", input_type=Boolean(optional=True), prefix="-t", doc=InputDocumentation(doc="query end position restriction")), ToolInput(tag="in_target_start_restriction", input_type=Boolean(optional=True), prefix="-u", doc=InputDocumentation(doc="target start position restriction")), ToolInput(tag="in_target_end_position", input_type=Boolean(optional=True), prefix="-v", doc=InputDocumentation(doc="target end position restriction")), ToolInput(tag="in_lh_window", input_type=Boolean(optional=True), prefix="-lhwindow", doc=InputDocumentation(doc="- sequence window given to alignment [50]")), ToolInput(tag="in_lh_seed", input_type=Boolean(optional=True), prefix="-lhseed", doc=InputDocumentation(doc="- seed score cutoff [10.0 bits]")), ToolInput(tag="in_lha_ln", input_type=Boolean(optional=True), prefix="-lhaln", doc=InputDocumentation(doc="- aln  score cutoff [8.0 bits]")), ToolInput(tag="in_lh_score", input_type=Boolean(optional=True), prefix="-lhscore", doc=InputDocumentation(doc="- sort final list by score (default by position)")), ToolInput(tag="in_lh_reject", input_type=Boolean(optional=True), prefix="-lhreject", doc=InputDocumentation(doc="[none/query/both] - overlap rejection criteria in greedy assembly [query]")), ToolInput(tag="in_lh_max", input_type=Boolean(optional=True), prefix="-lhmax", doc=InputDocumentation(doc="[20000] - maximum number of processed hits")), ToolInput(tag="in_lr", input_type=Boolean(optional=True), prefix="-lr", doc=InputDocumentation(doc="motif library is in Laurence's format (default is Ewan's)")), ToolInput(tag="in_ben", input_type=String(optional=True), prefix="-ben", doc=InputDocumentation(doc="library is in Ben's IUPAC format (default is Ewan's)")), ToolInput(tag="in_motif_lib", input_type=Boolean(optional=True), prefix="-motiflib", doc=InputDocumentation(doc="[filename] motif library file name")), ToolInput(tag="in_mm_motif", input_type=Boolean(optional=True), prefix="-mm_motif", doc=InputDocumentation(doc="[0.9]  Probability of a match in a motif")), ToolInput(tag="in_mm_cons", input_type=Boolean(optional=True), prefix="-mm_cons", doc=InputDocumentation(doc="[0.75] Probability of a match in a non-motif conserved")), ToolInput(tag="in_mm_spacer", input_type=Boolean(optional=True), prefix="-mm_spacer", doc=InputDocumentation(doc="[0.35] Probability of a match in a spacer")), ToolInput(tag="in_mm_motif_in_del", input_type=Boolean(optional=True), prefix="-mm_motif_indel", doc=InputDocumentation(doc="[0.00001] indel inside a motif")), ToolInput(tag="in_mm_cons_in_del", input_type=Boolean(optional=True), prefix="-mm_cons_indel", doc=InputDocumentation(doc="[0.025]   indel inside a conserved region")), ToolInput(tag="in_mm_spacer_in_del", input_type=Boolean(optional=True), prefix="-mm_spacer_indel", doc=InputDocumentation(doc="[0.1]    indel inside a spacer")), ToolInput(tag="in_mm_switch_motif", input_type=Boolean(optional=True), prefix="-mm_switch_motif", doc=InputDocumentation(doc="[0.05]    cost of switching to motif match")), ToolInput(tag="in_mm_switch_cons", input_type=Boolean(optional=True), prefix="-mm_switch_cons", doc=InputDocumentation(doc="[0.000001]  cost of switching to conserved match")), ToolInput(tag="in_tfb_pseudo", input_type=Boolean(optional=True), prefix="-tfb_pseudo", doc=InputDocumentation(doc="simple pseudo count, default 0.3")), ToolInput(tag="in_tfm_type", input_type=Boolean(optional=True), prefix="-tfm_type", doc=InputDocumentation(doc="[abs/rel/relmix] type of cutoff: absolute, relative, relative mixed")), ToolInput(tag="in_tfm_cut_off", input_type=Boolean(optional=True), prefix="-tfm_cutoff", doc=InputDocumentation(doc="(abs) bits cutoff for absolute matches, default 11.0")), ToolInput(tag="in_tfm_rel", input_type=Boolean(optional=True), prefix="-tfm_rel", doc=InputDocumentation(doc="[0.95] (rel/relmix) Relative to best possible score, accept if above irregardless of score")), ToolInput(tag="in_tfm_rel_bits", input_type=Boolean(optional=True), prefix="-tfm_relbits", doc=InputDocumentation(doc="[11.0] (relmix) If above relsoft and above this bits score, accept")), ToolInput(tag="in_hit_output", input_type=Boolean(optional=True), prefix="-hitoutput", doc=InputDocumentation(doc="[pseudoblast/xml/tab] pseudoblast by default")), ToolInput(tag="in_hit_help", input_type=Boolean(optional=True), prefix="-hithelp", doc=InputDocumentation(doc="more detailed help on hitlist formats")), ToolInput(tag="in_dy_mem", input_type=Boolean(optional=True), prefix="-dymem", doc=InputDocumentation(doc="memory style [default/linear/explicit]")), ToolInput(tag="in_kbyte", input_type=Boolean(optional=True), prefix="-kbyte", doc=InputDocumentation(doc="memory amount to use [4000]")), ToolInput(tag="in_dy_debug", input_type=Boolean(optional=True), prefix="-dydebug", doc=InputDocumentation(doc="drop into dynamite dp matrix debugger")), ToolInput(tag="in_pal_debug", input_type=Boolean(optional=True), prefix="-paldebug", doc=InputDocumentation(doc="print PackAln after debugger run if used")), ToolInput(tag="in_version", input_type=Boolean(optional=True), prefix="-version", doc=InputDocumentation(doc="show version and compile info")), ToolInput(tag="in_silent", input_type=Boolean(optional=True), prefix="-silent", doc=InputDocumentation(doc="No messages    on stderr")), ToolInput(tag="in_quiet", input_type=Boolean(optional=True), prefix="-quiet", doc=InputDocumentation(doc="No report/info on stderr")), ToolInput(tag="in_error_off_std", input_type=String(optional=True), prefix="-erroroffstd", doc=InputDocumentation(doc="warning messages to stderr")), ToolInput(tag="in_error_log", input_type=Boolean(optional=True), prefix="-errorlog", doc=InputDocumentation(doc="[file] Log warning messages to file")), ToolInput(tag="in_error_style", input_type=Boolean(optional=True), prefix="-errorstyle", doc=InputDocumentation(doc="[server/program] style of error reporting (default program)"))], outputs=[], container=None, version="v0.1.0")


if __name__ == "__main__":
    # or "cwl"
    Promoterwise_V0_1_0().translate("wdl", allow_empty_container=True)

